@@ -1,3 +1,4 @@
+from yaml import load
 from importlib import import_module
 
 
@@ -12,6 +13,12 @@ class TestManager(object):
         for testcase in testcases:
             self.add_testcase(testcase)
 
+    def add_testcases_from_yaml(self, path):
+        with open(path, 'r') as stream:
+            data = load(stream)
+        for url, cls in self._inner_dict(data):
+            self.add_testcase('%s:%s' % (url, cls))
+
     def add_testcase(self, testcase):
         testcase = self.maybe_dotted(testcase)
         key = testcase.__module__ + ':' + testcase.__name__
@@ -24,6 +31,18 @@ class TestManager(object):
             group.append(testcase)
             self.groups[name] = group
 
+    def _inner_dict(self, data, prefix=''):
+        if data is None:
+            return
+        for name, value in data.items():
+            if value is None:
+                continue
+            elif type(value) is dict:
+                yield from self._inner_dict(value, prefix + name + '.')
+            else:
+                for element in value:
+                    yield (prefix + name, element)
+
     def maybe_dotted(self, testcase):
         if type(testcase) is not str:
             return testcase
